
Navigation
============

.. toctree::
   :maxdepth: 2

   installation
   api-docs
   examples
   contributing
   authors

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
